[Scummvm-cvs-logs] scummvm master -> 7ee77cbd26f131ce00cd4a9ddf6515a283b646a3

kayahr k at ailis.de
Sat Jan 28 11:47:50 CET 2012


This automated email contains information about 2 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
9ee0526541 CREDITS: Added Tom Frost as contributor to WebOS port.
7ee77cbd26 WEBOS: Renamed "Touchpad Mode" to "Trackpad Mode" to prevent confusion because one of the target devices is called the "


Commit: 9ee05265418274c39153fd38669c6ff24fbe83b6
    https://github.com/scummvm/scummvm/commit/9ee05265418274c39153fd38669c6ff24fbe83b6
Author: Klaus Reimer (k at ailis.de)
Date: 2012-01-28T02:19:39-08:00

Commit Message:
CREDITS: Added Tom Frost as contributor to WebOS port.

Changed paths:
    AUTHORS
    COPYRIGHT
    devtools/credits.pl
    gui/credits.h



diff --git a/AUTHORS b/AUTHORS
index b28cd55..cf34598 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -477,6 +477,7 @@ Other contributions
      Daniel Schepler       - Final MI1 CD music support, initial Ogg Vorbis
                              support
      Andre Souza           - SDL-based OpenGL renderer
+     Tom Frost             - WebOS port contributions
 
   FreeSCI Contributors
   --------------------
diff --git a/COPYRIGHT b/COPYRIGHT
index e0a7aa9..9de8ac6 100644
--- a/COPYRIGHT
+++ b/COPYRIGHT
@@ -213,3 +213,4 @@ Xanathar "xanathar"
 Grant Yeager "glo_kidd"
 Benjamin W. Zale "junior_aepi"
 Yotam Barnoy "bluddy"
+Tom Frost "TomFrost"
diff --git a/devtools/credits.pl b/devtools/credits.pl
index 86ba741..73e66c2 100755
--- a/devtools/credits.pl
+++ b/devtools/credits.pl
@@ -1000,6 +1000,7 @@ begin_credits("Credits");
 				add_person("Edward Rudd", "urkle", "Fixes for playing MP3 versions of MI1/Loom audio");
 				add_person("Daniel Schepler", "dschepler", "Final MI1 CD music support, initial Ogg Vorbis support");
 				add_person("André Souza", "luke_br", "SDL-based OpenGL renderer");
+				add_person("Tom Frost", "TomFrost", "WebOS port contributions");
 			end_persons();
 		end_section();
 
diff --git a/gui/credits.h b/gui/credits.h
index dd839c2..77ec4f4 100644
--- a/gui/credits.h
+++ b/gui/credits.h
@@ -567,6 +567,8 @@ static const char *credits[] = {
 "C2""Final MI1 CD music support, initial Ogg Vorbis support",
 "C0""Andr\351 Souza",
 "C2""SDL-based OpenGL renderer",
+"C0""Tom Frost",
+"C2""WebOS port contributions",
 "",
 "C1""FreeSCI Contributors",
 "C0""Francois-R Boyer",


Commit: 7ee77cbd26f131ce00cd4a9ddf6515a283b646a3
    https://github.com/scummvm/scummvm/commit/7ee77cbd26f131ce00cd4a9ddf6515a283b646a3
Author: Klaus Reimer (k at ailis.de)
Date: 2012-01-28T02:44:31-08:00

Commit Message:
WEBOS: Renamed "Touchpad Mode" to "Trackpad Mode" to prevent confusion because one of the target devices is called the "HP Touchpad".

Changed paths:
    backends/events/webossdl/webossdl-events.cpp
    backends/events/webossdl/webossdl-events.h



diff --git a/backends/events/webossdl/webossdl-events.cpp b/backends/events/webossdl/webossdl-events.cpp
index 996ac48..286289f 100644
--- a/backends/events/webossdl/webossdl-events.cpp
+++ b/backends/events/webossdl/webossdl-events.cpp
@@ -151,8 +151,8 @@ bool WebOSSdlEventSource::handleMouseButtonDown(SDL_Event &ev,
 			event.type = Common::EVENT_LBUTTONDOWN;
 			processMouseEvent(event, _curX, _curY);
 		}
-		// If we're not in touchpad mode, move the cursor to the tap
-		if (!_touchpadMode) {
+		// If we're not in trackpad mode, move the cursor to the tap
+		if (!_trackpadMode) {
 			_curX = MIN(_screenX, MAX(0, 0 + ev.motion.x));
 			_curY = MIN(_screenY, MAX(0, 0 + ev.motion.y));
 			// If we're already clicking, hold it until after the move.
@@ -254,7 +254,7 @@ bool WebOSSdlEventSource::handleMouseMotion(SDL_Event &ev,
 			// If only one finger is on the screen and moving, that's
 			// the mouse pointer.
 			if (!_fingerDown[1] && !_fingerDown[2]) {
-				if (_touchpadMode) {
+				if (_trackpadMode) {
 					_curX = MIN(_screenX, MAX(0, _curX + ev.motion.xrel));
 					_curY = MIN(_screenY, MAX(0, _curY + ev.motion.yrel));
 				} else {
@@ -301,16 +301,16 @@ bool WebOSSdlEventSource::handleMouseMotion(SDL_Event &ev,
 						_queuedEscapeUpTime = g_system->getMillis() +
 							QUEUED_KEY_DELAY;
 					} else if (_dragDiffX[0] > 0 && _dragDiffX[1] > 0) {
-						// A swipe right toggles touchpad mode
-						_touchpadMode = !_touchpadMode;
-						g_system->showMouse(_touchpadMode);
-						// I18N: Touchpad mode toggle status.
-						Common::String dialogMsg(_("Touchpad mode is now"));
+						// A swipe right toggles trackpad mode
+						_trackpadMode = !_trackpadMode;
+						g_system->showMouse(_trackpadMode);
+						// I18N: Trackpad mode toggle status.
+						Common::String dialogMsg(_("Trackpad mode is now"));
 						dialogMsg += " ";
-						// I18N: Touchpad mode on or off.
-						dialogMsg += (_touchpadMode ? _("ON") : _("OFF"));
+						// I18N: Trackpad mode on or off.
+						dialogMsg += (_trackpadMode ? _("ON") : _("OFF"));
 						dialogMsg += ".\n";
 						// I18N: Instructions to toggle Touchpad mode.
 						dialogMsg +=
 							_("Swipe two fingers to the right to toggle.");
 						GUI::TimedMessageDialog dialog(dialogMsg, 1500);
@@ -377,11 +377,11 @@ bool WebOSSdlEventSource::pollEvent(Common::Event &event) {
 		// Set the initial dimensions
 		calculateDimensions();
 
 		// Having a mouse pointer on screen when not in Touchpad mode is poor
 		// interface design, because the user won't know whether to tap buttons
 		// or drag the pointer to them.  On the first poll, set the appropriate
 		// pointer visibility.
-		g_system->showMouse(_touchpadMode);
+		g_system->showMouse(_trackpadMode);
 		_firstPoll = false;
 	}
 
@@ -301,16 +301,16 @@ bool WebOSSdlEventSource::handleMouseMotion(SDL_Event &ev,
 						dialogMsg += ".\n";
-						// I18N: Instructions to toggle Touchpad mode.
+						// I18N: Instructions to toggle Trackpad mode.
 						dialogMsg +=
 							_("Swipe two fingers to the right to toggle.");
@@ -377,11 +377,11 @@ bool WebOSSdlEventSource::pollEvent(Common::Event &event) {
 		calculateDimensions();
 
-		// Having a mouse pointer on screen when not in Touchpad mode is poor
+		// Having a mouse pointer on screen when not in Trackpad mode is poor
 		// interface design, because the user won't know whether to tap buttons
 		// or drag the pointer to them.  On the first poll, set the appropriate
diff --git a/backends/events/webossdl/webossdl-events.h b/backends/events/webossdl/webossdl-events.h
index a36ee53..99ed310 100644
--- a/backends/events/webossdl/webossdl-events.h
+++ b/backends/events/webossdl/webossdl-events.h
@@ -45,7 +45,7 @@ public:
 			_dragStartTime(0), _dragging(false),
 			_curX(0), _curY(0),
 			_screenX(0), _screenY(0),
-			_touchpadMode(false), _autoDragMode(true),
+			_trackpadMode(false), _autoDragMode(true),
 			_doClick(true),
 			_queuedDragTime(0), _queuedEscapeUpTime(0), _queuedSpaceUpTime(0),
 			_queuedRUpTime(0),
@@ -80,8 +80,8 @@ protected:
 	// The drag distance for linear gestures
 	int _swipeDistX, _swipeDistY;
 
-	// Indicates if we're in touchpad mode or tap-to-move mode.
-	bool _touchpadMode;
+	// Indicates if we're in trackpad mode or tap-to-move mode.
+	bool _trackpadMode;
 
 	// Indicates if we're in automatic drag mode.
 	bool _autoDragMode;






More information about the Scummvm-git-logs mailing list